/* Two button pagination - previous / next */
.paginate_disabled_previous,
.paginate_enabled_previous,
.paginate_disabled_next,
.paginate_enabled_next {
  height: 19px;
  float: left;
  cursor: pointer;
  *cursor: hand;
  color: #111 !important;
}

.paginate_disabled_previous:hover,
.paginate_enabled_previous:hover,
.paginate_disabled_next:hover,
.paginate_enabled_next:hover {
  text-decoration: none !important;
}

.paginate_disabled_previous:active,
.paginate_enabled_previous:active,
.paginate_disabled_next:active,
.paginate_enabled_next:active {
  outline: none;
}

.paginate_disabled_previous,
.paginate_disabled_next {
  color: #666 !important;
}

.paginate_disabled_previous,
.paginate_enabled_previous {
  padding-left: 23px;
}

.paginate_disabled_next,
.paginate_enabled_next {
  padding-right: 23px;
  margin-left: 10px;
}

.paginate_enabled_previous {
  background: url('../images/back_enabled.png') no-repeat top left;
}

.paginate_enabled_previous:hover {
  background: url('../images/back_enabled_hover.png') no-repeat top left;
}

.paginate_disabled_previous {
  background: url('../images/back_disabled.png') no-repeat top left;
}

.paginate_enabled_next {
  background: url('../images/forward_enabled.png') no-repeat top right;
}

.paginate_enabled_next:hover {
  background: url('../images/forward_enabled_hover.png') no-repeat top right;
}

.paginate_disabled_next {
  background: url('../images/forward_disabled.png') no-repeat top right;
}