{% autoescape off %}
{% load jsmin %}
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery-1.9.1.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/django-helpers-require.js"></script>
<script type="text/javascript">
{% if app_name %}
window.__app_name = '{{ app_name }}';
{% endif %}
jQuery(function(){
    {% jsmin %}{% for code_block in code_blocks %}
        //noinspection JSCheckFunctionSignatures
        require({{ code_block.files }}, function () {
            {{ code_block.js_code }}
        });
    {% endfor %}{% endjsmin %}
});
</script>
{% endautoescape %}