<a href="{{ link|default:"#" }}" class="btn {% if color %} btn-{{ color }}{% endif %}">
    {% if icon %}
        <i class="icon {% if icon_color %}icon-{{ icon_color }} {% endif %}icon-{{ icon }}"></i>
    {% endif %}
    {% if text %}
        {{ text }}
    {% endif %}
</a>