<li class="{% if can_highlight %}active {% endif %}dropdown">
    <a class="dropdown-toggle" data-toggle="dropdown" href="{{ url }}">{{ text }}
        <b class="caret"></b>
    </a>
    {{ sub_menu }}
</li>