/* Full number pagination */
.paging_full_numbers {
  height: 22px;
  line-height: 22px;

  a {

    &:active {
      outline: none
    }

    &:hover {
      text-decoration: none;
    }

    &.paginate_button,
    &.paginate_active {
      border: 1px solid #aaa;
      -webkit-border-radius: 5px;
      -moz-border-radius: 5px;
      border-radius: 5px;
      padding: 2px 5px;
      margin: 0 3px;
      cursor: pointer;
      *cursor: hand;
      color: #333 !important;
    }

    &.paginate_button {
      background-color: #ddd;
    }

    &.paginate_button:hover {
      background-color: #ccc;
      text-decoration: none !important;
    }

    &.paginate_active {
      background-color: #99B3FF;
    }

    &.paginate_button_disabled {

    }

    &.first {

    }

    &.last {

    }

    &.previous {

    }

    &.next {

    }

  }
}
