/*
 * Table
 */
/* line 4, scss/table.scss */
table.dataTable {
  margin: 0 auto;
  clear: both;
  width: 100%;
}
/* line 12, scss/table.scss */
table.dataTable thead th {
  padding: 3px 18px 3px 10px;
  border-bottom: 1px solid black;
  font-weight: bold;
  cursor: pointer;
  *cursor: hand;
}
/* line 22, scss/table.scss */
table.dataTable tfoot th {
  padding: 3px 18px 3px 10px;
  border-top: 1px solid black;
  font-weight: bold;
}
/* line 29, scss/table.scss */
table.dataTable td {
  padding: 3px 10px;
}
/* line 33, scss/table.scss */
table.dataTable td.center, table.dataTable td.dataTables_empty {
  text-align: center;
}
/* line 41, scss/table.scss */
table.dataTable tr.odd {
  background-color: #a90000;
  /*
        td.sorting_1 {
          background-color: #D3D6FF;
        }
  
        td.sorting_2 {
          background-color: #DADCFF;
        }
  
        td.sorting_3 {
          background-color: #E0E2FF;
        }
  */
}
/* line 60, scss/table.scss */
table.dataTable tr.even {
  background-color: white;
  /*
        td.sorting_1 {
          background-color: #EAEBFF;
        }
  
        td.sorting_2 {
          background-color: #F2F3FF;
        }
  
        td.sorting_3 {
          background-color: #F9F9FF;
        }
  */
}

/*
 * Table wrapper
 */
/* line 83, scss/table.scss */
.dataTables_wrapper {
  position: relative;
  clear: both;
  *zoom: 1;
}

/*
 * Page length menu
 */
/* line 92, scss/table.scss */
.dataTables_length {
  float: left;
}

/*
 * Filter
 */
/* line 99, scss/table.scss */
.dataTables_filter {
  float: right;
  text-align: right;
}

/*
 * Table information
 */
/* line 107, scss/table.scss */
.dataTables_info {
  clear: both;
  float: left;
}

/*
 * Pagination
 */
/* line 4, scss/pagination.scss */
.dataTables_paginate {
  float: right;
  text-align: right;
}

/* Two button pagination - previous / next */
/* line 5, scss/pagination-two-button.scss */
.paginate_disabled_previous,
.paginate_enabled_previous,
.paginate_disabled_next,
.paginate_enabled_next {
  height: 19px;
  float: left;
  cursor: pointer;
  *cursor: hand;
  color: #111 !important;
}

/* line 16, scss/pagination-two-button.scss */
.paginate_disabled_previous:hover,
.paginate_enabled_previous:hover,
.paginate_disabled_next:hover,
.paginate_enabled_next:hover {
  text-decoration: none !important;
}

/* line 23, scss/pagination-two-button.scss */
.paginate_disabled_previous:active,
.paginate_enabled_previous:active,
.paginate_disabled_next:active,
.paginate_enabled_next:active {
  outline: none;
}

/* line 28, scss/pagination-two-button.scss */
.paginate_disabled_previous,
.paginate_disabled_next {
  color: #666 !important;
}

/* line 33, scss/pagination-two-button.scss */
.paginate_disabled_previous,
.paginate_enabled_previous {
  padding-left: 23px;
}

/* line 38, scss/pagination-two-button.scss */
.paginate_disabled_next,
.paginate_enabled_next {
  padding-right: 23px;
  margin-left: 10px;
}

/* line 43, scss/pagination-two-button.scss */
.paginate_enabled_previous {
  background: url("../images/back_enabled.png") no-repeat top left;
}

/* line 47, scss/pagination-two-button.scss */
.paginate_enabled_previous:hover {
  background: url("../images/back_enabled_hover.png") no-repeat top left;
}

/* line 51, scss/pagination-two-button.scss */
.paginate_disabled_previous {
  background: url("../images/back_disabled.png") no-repeat top left;
}

/* line 55, scss/pagination-two-button.scss */
.paginate_enabled_next {
  background: url("../images/forward_enabled.png") no-repeat top right;
}

/* line 59, scss/pagination-two-button.scss */
.paginate_enabled_next:hover {
  background: url("../images/forward_enabled_hover.png") no-repeat top right;
}

/* line 63, scss/pagination-two-button.scss */
.paginate_disabled_next {
  background: url("../images/forward_disabled.png") no-repeat top right;
}

/* Full number pagination */
/* line 2, scss/pagination-full.scss */
.paging_full_numbers {
  height: 22px;
  line-height: 22px;
}
/* line 8, scss/pagination-full.scss */
.paging_full_numbers a:active {
  outline: none;
}
/* line 12, scss/pagination-full.scss */
.paging_full_numbers a:hover {
  text-decoration: none;
}
/* line 17, scss/pagination-full.scss */
.paging_full_numbers a.paginate_button, .paging_full_numbers a.paginate_active {
  border: 1px solid #aaa;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  padding: 2px 5px;
  margin: 0 3px;
  cursor: pointer;
  *cursor: hand;
  color: #333 !important;
}
/* line 29, scss/pagination-full.scss */
.paging_full_numbers a.paginate_button {
  background-color: #ddd;
}
/* line 33, scss/pagination-full.scss */
.paging_full_numbers a.paginate_button:hover {
  background-color: #ccc;
  text-decoration: none !important;
}
/* line 38, scss/pagination-full.scss */
.paging_full_numbers a.paginate_active {
  background-color: #99B3FF;
}

/*
 * Processing indicator
 */
/* line 117, scss/table.scss */
.dataTables_processing {
  position: absolute;
  top: 50%;
  left: 50%;
  width: 250px;
  height: 30px;
  margin-left: -125px;
  margin-top: -15px;
  padding: 14px 0 2px 0;
  border: 1px solid #ddd;
  text-align: center;
  color: #999;
  font-size: 14px;
  background-color: white;
}

/*
 * Sorting
 */
/* line 4, scss/sorting.scss */
.sorting {
  background: url("../images/sort_both.png") no-repeat center right;
}

/* line 8, scss/sorting.scss */
.sorting_asc {
  background: url("../images/sort_asc.png") no-repeat center right;
}

/* line 12, scss/sorting.scss */
.sorting_desc {
  background: url("../images/sort_desc.png") no-repeat center right;
}

/* line 16, scss/sorting.scss */
.sorting_asc_disabled {
  background: url("../images/sort_asc_disabled.png") no-repeat center right;
}

/* line 20, scss/sorting.scss */
.sorting_desc_disabled {
  background: url("../images/sort_desc_disabled.png") no-repeat center right;
}

/* line 25, scss/sorting.scss */
table.dataTable thead th:active,
table.dataTable thead td:active {
  outline: none;
}

/*
 * Scrolling
 */
/* line 4, scss/scrolling.scss */
.dataTables_scroll {
  clear: both;
}

/* line 8, scss/scrolling.scss */
.dataTables_scrollBody {
  *margin-top: -1px;
  -webkit-overflow-scrolling: touch;
}
