<div class="control-group{% if field.errors %} error{% endif %}" id="container_{{ field.id_for_label }}">

    <div class="control-label">
        <label class="control-label" for="{{ field.id_for_label }}">{{ field.label }} : </label>
    </div>

    <div class="controls">
        {{ field }}
        {% if field.errors %}
            {% for error_msg in field.errors %}
                <label class="help-block" for="{{ field.id_for_label }}">
                    {{ error_msg }}
                </label>
            {% endfor %}
        {% else %}
            {% if field.help_text %}
                <label for="{{ field.id_for_label }}">
                    <span class="help-block">{{ field.help_text }}</span>
                </label>
            {% endif %}
        {% endif %}
    </div>
</div>