/*
 * Table
 */
table.dataTable {

  margin: 0 auto;
  clear: both;
  width: 100%;


  thead {
    th {
      padding: 3px 18px 3px 10px;
      border-bottom: 1px solid black;
      font-weight: bold;
      cursor: pointer;
      *cursor: hand;
    }
  }

  tfoot {
    th {
      padding: 3px 18px 3px 10px;
      border-top: 1px solid black;
      font-weight: bold;
    }
  }

  td {
    padding: 3px 10px;

    &.center,
    &.dataTables_empty {
      text-align: center;
    }

  }

  tr {

    &.odd {
      background-color: #a90000;

/*
      td.sorting_1 {
        background-color: #D3D6FF;
      }

      td.sorting_2 {
        background-color: #DADCFF;
      }

      td.sorting_3 {
        background-color: #E0E2FF;
      }
*/

    }

    &.even {
      background-color: white;

/*
      td.sorting_1 {
        background-color: #EAEBFF;
      }

      td.sorting_2 {
        background-color: #F2F3FF;
      }

      td.sorting_3 {
        background-color: #F9F9FF;
      }
*/
    }
  }
}

/*
 * Table wrapper
 */
.dataTables_wrapper {
  position: relative;
  clear: both;
  *zoom: 1;
}

/*
 * Page length menu
 */
.dataTables_length {
  float: left;
}

/*
 * Filter
 */
.dataTables_filter {
  float: right;
  text-align: right;
}

/*
 * Table information
 */
.dataTables_info {
  clear: both;
  float: left;
}

@import "pagination";

/*
 * Processing indicator
 */
.dataTables_processing {
  position: absolute;
  top: 50%;
  left: 50%;
  width: 250px;
  height: 30px;
  margin-left: -125px;
  margin-top: -15px;
  padding: 14px 0 2px 0;
  border: 1px solid #ddd;
  text-align: center;
  color: #999;
  font-size: 14px;
  background-color: white;
}

@import "sorting";
@import "scrolling";

