<div class="row" id="container_{{ field.id_for_label }}">
    <div class="rowleft">{{ field.label_tag }}</div>
    <div class="rowright{% if field.errors %} error{% endif %}">
        {{ field }}
        {% if field.errors %}
            {% for error_msg in field.errors %}
                <label for="{{ field.id_for_label }}"><span class="error">{{ error_msg }}</span></label>
            {% endfor %}
        {% else %}
            {% if field.help_text %}
                <label for="{{ field.id_for_label }}"><span>{{ field.help_text }}</span></label>
            {% endif %}
        {% endif %}
    </div>
<div class="clearfix"></div>
</div>