{% extends base|default:"base.html" %}
{% block contents %}
    <h2>Confirm Delete</h2>
    <form action="" method="post">
        <input type="hidden" value="{{ token }}" name="token" />
        {% csrf_token %}
        <img src="{{ image.thumbnail }}" alt="{{ image.alternate_text }}"/>

        <div>Are you sure to delete this image from the system ?</div>
        <div>This will remove this image from where ever this is used.</div>
        <div class="row">
            <button type="submit" class="medium red" value="yes" name="submit">
                <span>Yes, I want to delete this image</span>
            </button>
            <button type="submit" class="medium green" value="no" name="submit">
                <span>No, I changed my mind. I don't want to delete this image.</span>
            </button>
        </div>
    </form>
{% endblock %}