#image-manager {
    margin: 10px;
}

#image-manager #list-images {

}

#image-manager #list-images .single-image {
    float: left;
    position: relative;
    margin: 10px;
    overflow: hidden;
}

#image-manager #list-images .single-image img {
    display: block;
}

#image-manager #list-images .single-image .name {
    display: block;
    text-align: center;
    font-weight: bold;
}

#image-manager #list-images .single-image .actions {
    position: absolute;
    -webkit-transition: all 0.2s;
    -moz-transition: all 0.2s;
    transition: all 0.2s;
    height: 30px;
    width: 100%;
    top: -40px;
    text-align: center;
}

#image-manager #list-images .single-image .actions a {
    padding: 5px 3px;
    border-radius: 15px;
    display: inline-block;
    text-indent: -999px;
    width: 32px;
    height: 32px;
}

#image-manager #list-images .single-image:hover .actions {
    top: 50%;
    margin-top: -27px;
}


#image-manager #list-images .single-image:hover .actions .delete {
    background: url('images/delete.png') no-repeat center center;
}

#image-manager #list-images .single-image:hover .actions .view {
    background: url('images/view.png') no-repeat center center;
}

#image-manager #list-images .single-image:hover .actions .edit {
    background: url('images/edit.png') no-repeat center center;
}