$.dj.xEditable("#" + '{{ field_id }}', "#" + '{{ field_id }}', '{{ save_url }}', {
    pk : '{{ pk }}',
    name : '{{ name }}',
    placement : 'top',
    title : '{{ title }}',

    type : 'textarea',
    rows : {{ rows }}
});