$.dj.xEditable("#" + '{{ field_id }}', "#" + '{{ field_id }}', '{{ save_url }}', {
    type : 'text',
    pk : '{{ pk }}',
    name : '{{ name }}',
    placement : 'top',
    title : '{{ title }}'
});