# coding=utf-8
icons = {
    'glass': 'icon-glass',
    'music': 'icon-music',
    'search': 'icon-search',
    'envelope': 'icon-envelope',
    'heart': 'icon-heart',
    'star': 'icon-star',
    'star-empty': 'icon-star-empty',
    'user': 'icon-user',
    'film': 'icon-film',
    'th-large': 'icon-th-large',
    'th': 'icon-th',
    'th-list': 'icon-th-list',
    'ok': 'icon-ok',
    'remove': 'icon-remove',
    'zoom-in': 'icon-zoom-in',
    'zoom-out': 'icon-zoom-out',
    'off': 'icon-off',
    'signal': 'icon-signal',
    'cog': 'icon-cog',
    'trash': 'icon-trash',
    'home': 'icon-home',
    'file': 'icon-file',
    'time': 'icon-time',
    'road': 'icon-road',
    'download-alt': 'icon-download-alt',
    'download': 'icon-download',
    'upload': 'icon-upload',
    'inbox': 'icon-inbox',
    'play-circle': 'icon-play-circle',
    'repeat': 'icon-repeat',
    'refresh': 'icon-refresh',
    'list-alt': 'icon-list-alt',
    'lock': 'icon-lock',
    'flag': 'icon-flag',
    'headphones': 'icon-headphones',
    'volume-off': 'icon-volume-off',
    'volume-down': 'icon-volume-down',
    'volume-up': 'icon-volume-up',
    'qrcode': 'icon-qrcode',
    'barcode': 'icon-barcode',
    'tag': 'icon-tag',
    'tags': 'icon-tags',
    'book': 'icon-book',
    'bookmark': 'icon-bookmark',
    'print': 'icon-print',
    'camera': 'icon-camera',
    'font': 'icon-font',
    'bold': 'icon-bold',
    'italic': 'icon-italic',
    'text-height': 'icon-text-height',
    'text-width': 'icon-text-width',
    'align-left': 'icon-align-left',
    'align-center': 'icon-align-center',
    'align-right': 'icon-align-right',
    'align-justify': 'icon-align-justify',
    'list': 'icon-list',
    'indent-left': 'icon-indent-left',
    'indent-right': 'icon-indent-right',
    'facetime-video': 'icon-facetime-video',
    'picture': 'icon-picture',
    'pencil': 'icon-pencil',
    'map-marker': 'icon-map-marker',
    'adjust': 'icon-adjust',
    'tint': 'icon-tint',
    'edit': 'icon-edit',
    'share': 'icon-share',
    'check': 'icon-check',
    'move': 'icon-move',
    'step-backward': 'icon-step-backward',
    'fast-backward': 'icon-fast-backward',
    'backward': 'icon-backward',
    'play': 'icon-play',
    'pause': 'icon-pause',
    'stop': 'icon-stop',
    'forward': 'icon-forward',
    'fast-forward': 'icon-fast-forward',
    'step-forward': 'icon-step-forward',
    'eject': 'icon-eject',
    'chevron-left': 'icon-chevron-left',
    'chevron-right': 'icon-chevron-right',
    'plus-sign': 'icon-plus-sign',
    'minus-sign': 'icon-minus-sign',
    'remove-sign': 'icon-remove-sign',
    'ok-sign': 'icon-ok-sign',
    'question-sign': 'icon-question-sign',
    'info-sign': 'icon-info-sign',
    'screenshot': 'icon-screenshot',
    'remove-circle': 'icon-remove-circle',
    'ok-circle': 'icon-ok-circle',
    'ban-circle': 'icon-ban-circle',
    'arrow-left': 'icon-arrow-left',
    'arrow-right': 'icon-arrow-right',
    'arrow-up': 'icon-arrow-up',
    'arrow-down': 'icon-arrow-down',
    'share-alt': 'icon-share-alt',
    'resize-full': 'icon-resize-full',
    'resize-small': 'icon-resize-small',
    'plus': 'icon-plus',
    'minus': 'icon-minus',
    'asterisk': 'icon-asterisk',
    'exclamation-sign': 'icon-exclamation-sign',
    'gift': 'icon-gift',
    'leaf': 'icon-leaf',
    'fire': 'icon-fire',
    'eye-open': 'icon-eye-open',
    'eye-close': 'icon-eye-close',
    'warning-sign': 'icon-warning-sign',
    'plane': 'icon-plane',
    'calendar': 'icon-calendar',
    'random': 'icon-random',
    'comment': 'icon-comment',
    'magnet': 'icon-magnet',
    'chevron-up': 'icon-chevron-up',
    'chevron-down': 'icon-chevron-down',
    'retweet': 'icon-retweet',
    'shopping-cart': 'icon-shopping-cart',
    'folder-close': 'icon-folder-close',
    'folder-open': 'icon-folder-open',
    'resize-vertical': 'icon-resize-vertical',
    'resize-horizontal': 'icon-resize-horizontal',
    'hdd': 'icon-hdd',
    'bullhorn': 'icon-bullhorn',
    'bell': 'icon-bell',
    'certificate': 'icon-certificate',
    'thumbs-up': 'icon-thumbs-up',
    'thumbs-down': 'icon-thumbs-down',
    'hand-right': 'icon-hand-right',
    'hand-left': 'icon-hand-left',
    'hand-up': 'icon-hand-up',
    'hand-down': 'icon-hand-down',
    'circle-arrow-right': 'icon-circle-arrow-right',
    'circle-arrow-left': 'icon-circle-arrow-left',
    'circle-arrow-up': 'icon-circle-arrow-up',
    'circle-arrow-down': 'icon-circle-arrow-down',
    'globe': 'icon-globe',
    'wrench': 'icon-wrench',
    'tasks': 'icon-tasks',
    'filter': 'icon-filter',
    'briefcase': 'icon-briefcase',
    'fullscreen': 'icon-fullscreen',
}

colors = {
    'primary': 'btn-primary',
    'info': 'btn-info',
    'success': 'btn-success',
    'warning': 'btn-warning',
    'danger': 'btn-danger',
    'inverse': 'btn-inverse',
    'link': 'btn-link',
}

sizes = {
    'large': 'btn-large',
    'small': 'btn-small',
    'mini': 'btn-mini',
}


__all__ = ('sizes', 'icons', 'colors')

def gen_colors():
    x = "btn-primary btn-info btn-success btn-warning btn-danger btn-inverse btn-link"
    print 'colors = {'
    for icon in x.split(' '):
        name = icon[4:]
        print "'" + name + "'",
        print ':',
        print "'" + icon + "',"
    print '}'


def gen_icons():
    x = "icon-glass icon-music icon-search icon-envelope icon-heart icon-star icon-star-empty icon-user icon-film icon-th-large icon-th icon-th-list icon-ok icon-remove icon-zoom-in icon-zoom-out icon-off icon-signal icon-cog icon-trash icon-home icon-file icon-time icon-road icon-download-alt icon-download icon-upload icon-inbox icon-play-circle icon-repeat icon-refresh icon-list-alt icon-lock icon-flag icon-headphones icon-volume-off icon-volume-down icon-volume-up icon-qrcode icon-barcode icon-tag icon-tags icon-book icon-bookmark icon-print icon-camera icon-font icon-bold icon-italic icon-text-height icon-text-width icon-align-left icon-align-center icon-align-right icon-align-justify icon-list icon-indent-left icon-indent-right icon-facetime-video icon-picture icon-pencil icon-map-marker icon-adjust icon-tint icon-edit icon-share icon-check icon-move icon-step-backward icon-fast-backward icon-backward icon-play icon-pause icon-stop icon-forward icon-fast-forward icon-step-forward icon-eject icon-chevron-left icon-chevron-right icon-plus-sign icon-minus-sign icon-remove-sign icon-ok-sign icon-question-sign icon-info-sign icon-screenshot icon-remove-circle icon-ok-circle icon-ban-circle icon-arrow-left icon-arrow-right icon-arrow-up icon-arrow-down icon-share-alt icon-resize-full icon-resize-small icon-plus icon-minus icon-asterisk icon-exclamation-sign icon-gift icon-leaf icon-fire icon-eye-open icon-eye-close icon-warning-sign icon-plane icon-calendar icon-random icon-comment icon-magnet icon-chevron-up icon-chevron-down icon-retweet icon-shopping-cart icon-folder-close icon-folder-open icon-resize-vertical icon-resize-horizontal icon-hdd icon-bullhorn icon-bell icon-certificate icon-thumbs-up icon-thumbs-down icon-hand-right icon-hand-left icon-hand-up icon-hand-down icon-circle-arrow-right icon-circle-arrow-left icon-circle-arrow-up icon-circle-arrow-down icon-globe icon-wrench icon-tasks icon-filter icon-briefcase icon-fullscreen"
    print 'icons = {'
    for icon in x.split(' '):
        name = icon[5:]
        print "'" + name + "'",
        print ':',
        print "'" + icon + "',"
    print '}'


if __name__ == "__main__":
    gen_colors()
