{% if data|length %}
    <div class="btn-group">
        {% for button in data %}
            <a href="{{ button.link|default:"#" }}" class="btn {% if button.color %} btn-{{ button.color }}{% endif %}">
                {% if button.icon %}
                    <i class="icon {% if button.icon_color %}icon-{{ button.icon_color }} {% endif %}icon-{{ button.icon }}"></i>
                {% endif %}
                {% if button.text %}
                    {{ button.text }}
                {% endif %}
            </a>
        {% endfor %}

    </div>
{% endif %}
